@@ -191,7 +191,7 @@ class ExplicitFileSource(object):
             shutil.copyfile(from_path, to_path)
 
 
-def assemble_experiment_temp_dir(config, for_remote=False):
+def assemble_experiment_temp_dir(log, config, for_remote=False):
     """Create a temp directory from which to run an experiment.
     If for_remote is set to True the preparation includes bundling
     the local dallinger version if it was installed in editable mode.
@@ -292,10 +292,15 @@ def assemble_experiment_temp_dir(config, for_remote=False):
     requirements_path = Path(dst) / "requirements.txt"
     # Overwrite the requirements.txt file with the contents of the constraints.txt file
     (Path(dst) / "constraints.txt").replace(requirements_path)
-
     if for_remote:
         dallinger_path = get_editable_dallinger_path()
         if dallinger_path:
+            log(
+                "Dallinger is installed as an editable package, "
+                "and so will be copied and deployed in its current state, "
+                "ignoring the dallinger version specified in your experiment's "
+                "requirements.txt file!"
+            )
             egg_name = build_and_place(dallinger_path, dst)
             # Replace the line about dallinger in requirements.txt so that
             # it refers to the just generated package
@@ -320,9 +325,10 @@ def setup_experiment(
     # Verify that the Postgres server is running.
     if local_checks:
         try:
+            log("Checking your local Postgres database connection...")
             db.check_connection()
         except Exception:
-            log("There was a problem connecting to the Postgres database!")
+            log("There was a problem connecting!")
             raise
 
         # Check that the demo-specific requirements are satisfied.
@@ -363,7 +369,7 @@ def setup_experiment(
     if not config.get("dashboard_password", None):
         config.set("dashboard_password", fake.password(length=20, special_chars=False))
 
-    temp_dir = assemble_experiment_temp_dir(config, for_remote=not local_checks)
+    temp_dir = assemble_experiment_temp_dir(log, config, for_remote=not local_checks)
     log("Deployment temp directory: {}".format(temp_dir), chevrons=False)
 
     # Zip up the temporary directory and place it in the cwd.
@@ -500,7 +506,7 @@ def deploy_sandbox_shared_setup(
         config.load()
     heroku.sanity_check(config)
     (heroku_app_id, tmp) = setup_experiment(
-        log, debug=False, app=app, exp_config=exp_config
+        log, debug=False, app=app, exp_config=exp_config, local_checks=False
     )
 
     # Register the experiment using all configured registration services.
@@ -747,6 +753,12 @@ class DebugDeployment(HerokuLocalDeployment):
             "FLASK_SECRET_KEY": codecs.encode(os.urandom(16), "hex").decode("ascii"),
         }
 
+    def with_proxy_port(self, url):
+        if self.proxy_port is not None:
+            self.out.log("Using proxy port {}".format(self.proxy_port))
+            url = url.replace(str(get_config().get("base_port")), self.proxy_port)
+        return url
+
     def configure(self):
         super(DebugDeployment, self).configure()
         if self.bot:
@@ -767,7 +779,7 @@ class DebugDeployment(HerokuLocalDeployment):
         else:
             if result["status"] == "success":
                 self.out.log(result["recruitment_msg"])
-                dashboard_url = "{}/dashboard/".format(get_base_url())
+                dashboard_url = self.with_proxy_port("{}/dashboard/".format(base_url))
                 self.display_dashboard_access_details(dashboard_url)
                 if not self.no_browsers:
                     self.open_dashboard(dashboard_url)
@@ -793,10 +805,8 @@ class DebugDeployment(HerokuLocalDeployment):
         if self.no_browsers:
             self.out.log(recruiters.NEW_RECRUIT_LOG_PREFIX + ": " + match.group(1))
             return
-        url = match.group(1)
-        if self.proxy_port is not None:
-            self.out.log("Using proxy port {}".format(self.proxy_port))
-            url = url.replace(str(get_config().get("base_port")), self.proxy_port)
+        url = self.with_proxy_port(match.group(1))
+
         open_browser(url)
 
     def display_dashboard_access_details(self, url):
