@@ -433,20 +433,27 @@ var dallinger = (function () {
           console.log(resp);
           $('.btn-success').prop('disabled', false);
           dlgr.identity.participantId = resp.participant.id;
-          if (resp.quorum && resp.quorum.n !== resp.quorum.q) {
-            if (resp.quorum.overrecruited) {
-              dlgr.skip_experiment = true;
-              // reached quorum; resolve immediately
+          if (! resp.quorum) {  // We're not using a waiting room.
+            deferred.resolve();
+            return;
+          }
+
+          // We've got a waiting room, so run waiting room checks...
+          if (resp.quorum.overrecruited) {
+            // If we're overrecruited, no need to check anything else.
+            dlgr.skip_experiment = true;
+            deferred.resolve();
+            return;
+          }
+
+          if (resp.quorum.n < resp.quorum.q) {
+            // wait for quorum, then resolve
+            dlgr.updateProgressBar(resp.quorum.n, resp.quorum.q);
+            dlgr.waitForQuorum().done(function () {
               deferred.resolve();
-            } else {
-              // wait for quorum, then resolve
-              dlgr.updateProgressBar(resp.quorum.n, resp.quorum.q);
-              dlgr.waitForQuorum().done(function () {
-                deferred.resolve();
-              });
-            }
+            });
           } else {
-            // no quorum; resolve immediately
+            // last through the door; resolve immediately
             deferred.resolve();
           }
         });
@@ -611,10 +618,11 @@ var dallinger = (function () {
    * @param {string} [name=questionnaire] - optional questionnaire name
    */
   dlgr.submitQuestionnaire = function (name) {
-    var inputs = $("form :input");
+    var $inputs = $("form :input");
+    var $button = $("button#submit-questionnaire");
     var spinner = dlgr.BusyForm();
     var formDict = {};
-    $.each(inputs, function(key, input) {
+    $.each($inputs, function(key, input) {
       if (input.name !== "") {
         formDict[input.name] = $(input).val();
       }
@@ -625,9 +633,16 @@ var dallinger = (function () {
       number: 1,
       response: JSON.stringify(formDict)
     });
-    spinner.freeze([$('form :input')]);
-    xhr.done(dlgr.submitAssignment);
-    xhr.always(function () { spinner.unfreeze(); });
+    spinner.freeze([$inputs, $button]);
+    xhr.done(function () {
+      dlgr.submitAssignment().done(function () {
+       spinner.unfreeze();
+      }).fail(function (rejection) {
+        dlgr.error(rejection);
+      });
+    }).fail(function (rejection) {
+      dlgr.error(rejection);
+    });
   };
 
   /**
